@@ -6,15 +6,17 @@ package Mnet::T;
 use warnings;
 use strict;
 use Carp;
-use Config;
-use Mnet;
+use Exporter qw ( import );
 use Test::More;
 
+# export function names
+our @EXPORT_OK = qw( mnet_test_perl );
 
 
-sub test_perl {
 
-# $result = Mnet::T::test_perl(\%specs)
+sub mnet_test_perl {
+
+# $result = mnet_test_perl(\%specs)
 # purpose: test w/pre/perl/post/filter/expect/debug, for mnet .t scripts
 # \%specs: input test specification hash reference, see below
 # $result: true if test passed
@@ -27,14 +29,13 @@ sub test_perl {
 #       post    => $sh_code',    # shell code to execute after perl code
 #       filter  => $sh_command,  # shell code perl output is piped through
 #       expect  => $text,        # match with filtered output for pass/fail
-#       debug   => $debug_args,  # perl args to re-run test after failure
+#       debug   => $debug_args,  # perl args to re-run test after a failure
 #   }
 #
 # note that leading spaces are removed lines of text stored in exect key
-# note that debug re-run exports MNET_TEST_PERL_DEBUG=1, even if null
 #
-#   use Mnet::T qw( test_perl );
-#   test_perl({
+#   use Mnet::T qw( mnet_test_perl );
+#   mnet_test_perl({
 #       name    => 'test',
 #       perl    => <<'    perl-eof',
 #           use warnings;
@@ -58,25 +59,16 @@ sub test_perl {
 #
 # troubleshoot a single test with: INIT { our $mnet_test_perl = $name_re }
 
-#? problem on cpantesters with grep on one sparc64-openbsd system
-#   test filters with grep get error 'grep: -: No such file or directory'
-#   no sed errors, no defined aliases, both commands in /usr/bin, in $PATH
-#   grep gives this error if run with no stdin, example: `grep test -`
-#   dosn't matter if it's one grep command, or multiple, complex or simple
-#   debuged with new if-block for not $result, syswrite stderr with extra info
-#   $Config::Config{archname} code can skip, better to simple/accurate/fail
-
     # read input specs
     my $specs = shift;
 
-    # note test name and caller info
+    # note test name
     my $name = $specs->{name};
-    my @caller = caller();
 
     # skip if global mnet_test_perl var is set and test doesn't match
     #   makes it easy to troubleshoot one test in a .t script full of tests
     if ($main::mnet_test_perl and $name !~ /\Q$main::mnet_test_perl\E/) {
-        SKIP: { skip("$name (main::mnet_test_perl)", 1); };
+        SKIP: { skip("$name (main::mnet_test_perl dosn't match)", 1); };
         return 1;
     }
 
@@ -86,13 +78,12 @@ sub test_perl {
     }
 
     # prepare command for test
-    my $command = _test_perl_command($specs);
+    my $command = _mnet_test_perl_command($specs);
 
     # append filter to test command, if one was specified
-    #   remove leading and trailing blank lines before shell piping
     if ($specs->{filter}) {
-        $specs->{filter} =~ s/(^\s+|\s+$)//mg;
-        $command .= "| $specs->{filter}";
+        ( my $filter = $specs->{filter} ) =~ s/'/'"'"'/g;
+        $command .= "| $filter";
     }
 
     # trim expect text, allows for indents
@@ -102,42 +93,33 @@ sub test_perl {
     $specs->{expect} =~ s/(^\n+|\n+$)//g;
 
     # get output from command, remove leading/trailing blank lines
-    ( my $output = `( $command ) 2>&1` ) =~ s/(^\n+|\n+$)//g;
+    ( my $output = `$command` ) =~ s/(^\n+|\n+$)//g;
 
     # compare command output to expected output
     #   added leading cr makes for cleaner Test::More::is output
     my $result = Test::More::is( "\n$output", "\n$specs->{expect}", $name);
 
     # re-run test with debug args if test failed and debug key was set
-    if (not $result) {
-        if ($specs->{debug} or $specs->{filter}) {
-            my $output = "\npre/perl/post debug for failed '$name'\n";
-            $output .= "   called from $caller[1] line $caller[2]\n\n";
-            my $command = _test_perl_command($specs, "debug");
-            $output .= "COMMAND STARTING\n$command\nCOMMAND FINISHED\n";
-            $output .= "UNFILTERED OUTPUT STARTING";
-            $output .= `( export MNET_TEST_PERL_DEBUG=1; $command ) 2>&1`;
-            $output .= "UNFILTERED OUTPUT FINISHED\n";
-            $output .= "FILTER STARTING\n$specs->{filter}\nFILTER FINISHED\n"
-                if $specs->{filter};
-            syswrite STDERR, "## $_\n" foreach split(/\n/, $output);
-            syswrite STDERR, "##\n";
-        } else {
-            syswrite STDERR, "##    called from $caller[1] line $caller[2]\n\n";
-        }
+    if (not $result and $specs->{debug}) {
+        my $output = "\npre/perl/post $specs->{debug} for failed '$name'\n\n";
+        my $command = _mnet_test_perl_command($specs, "debug");
+        $output .= "COMMAND STARTING\n$command\nCOMMAND FINISHED\n";
+        $output .= `( $command ) 2>&1`;
+        print "## $_\n" foreach split(/\n/, $output);
+        print "##\n";
     }
 
-    # finished test_perl function, return result
+    # finished mnet_test_perl function, return result
     return $result;
 }
 
 
 
-sub _test_perl_command {
+sub _mnet_test_perl_command {
 
-# $command = _test_perl_command(\%specs, $debug)
+# $command = _mnet_test_perl_command(\%specs, $debug)
 # purpose: prepare pre, perl, and post test command string
-# \%specs: hash ref of test specifications, refer to test_perl function
+# \%specs: hash ref of test specifications, refer to mnet_test_perl function
 # $debug: optional debug arguments, set when test needs to be re-run after fail
 # $command: output command string ready to run with Test::More::is
 
@@ -149,7 +131,7 @@ sub _test_perl_command {
 
     # append pre shell code, if specified
     if ($specs->{pre}) {
-        $specs->{pre} =~ s/(^\s+|\s+$)//g;
+        $specs->{pre} =~ s/\n+$//;
         $command .= "echo 'PRE STARTING';" if $debug;
         $command .= "$specs->{pre};";
         $command .= "echo 'PRE FINISHED'; echo;" if $debug;
@@ -160,12 +142,12 @@ sub _test_perl_command {
     ( my $perl = $specs->{perl} ) =~ s/'/'"'"'/g;
     $command .= "echo '$perl' | $^X - ";
     $command .= $specs->{args} if defined $specs->{args};
-    $command .= " " . $specs->{debug} if $debug and defined $specs->{debug};
+    $command .= " " . $specs->{debug} if defined $debug;
     $command .= ";";
 
     # append post shell code, if specified
     if ($specs->{post}) {
-        $specs->{post} =~ s/(^\s+|\s+$)//g;
+        $specs->{post} =~ s/\n+$//;
         $command .= "echo; echo 'POST STARTING';" if $debug;
         $command .= "$specs->{post};";
         $command .= "echo 'POST FINISHED';" if $debug;
@@ -174,10 +156,6 @@ sub _test_perl_command {
     # use subshell and redirection to capture all command output
     $command = "( echo; $command ) 2>&1" if $command;
 
-    # warn that `echo -n` doesn't work in darwin os, use printf instead
-    croak("echo -n doesn't work on darwin os, use printf instead")
-        if $command =~ /echo -n/;
-
     # finished _test_per_command, return command
     return $command;
 }
